@@ -1,5 +1,3 @@
-/* $Xorg: bdfread.c,v 1.5 2001/02/09 02:04:01 xorgcvs Exp $ */
-
 /************************************************************************
 Copyright 1989 by Digital Equipment Corporation, Maynard, Massachusetts.
 
@@ -50,15 +48,12 @@ other dealings in this Software without prior written authorization
 from The Open Group.
 
 */
-/* $XFree86: xc/lib/font/bitmap/bdfread.c,v 1.12tsi Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#ifndef FONTMODULE
 #include <ctype.h>
-#endif
 #include <X11/fonts/fntfilst.h>
 #include <X11/fonts/fontutil.h>
 /* use bitmap structure */
@@ -81,7 +76,7 @@ extern int  bdfFileLineNum;
 /***====================================================================***/
 
 static Bool
-bdfReadBitmap(CharInfoPtr pCI, FontFilePtr file, int bit, int byte, 
+bdfReadBitmap(CharInfoPtr pCI, FontFilePtr file, int bit, int byte,
 	      int glyph, int scan, CARD32 *sizes)
 {
     int         widthBits,
@@ -102,9 +97,9 @@ bdfReadBitmap(CharInfoPtr pCI, FontFilePtr file, int bit, int byte,
 
     widthBytes = BYTES_PER_ROW(widthBits, glyph);
     if (widthBytes * height > 0) {
-	picture = (unsigned char *) xalloc(widthBytes * height);
+	picture = malloc(widthBytes * height);
 	if (!picture) {
-          bdfError("Couldn't allocate picture (%d*%d)\n", widthBytes, height);        
+          bdfError("Couldn't allocate picture (%d*%d)\n", widthBytes, height);
 	    goto BAILOUT;
       }
     } else
@@ -192,7 +187,7 @@ bdfReadBitmap(CharInfoPtr pCI, FontFilePtr file, int bit, int byte,
     return (TRUE);
 BAILOUT:
     if (picture)
-	xfree(picture);
+	free(picture);
     pCI->bits = NULL;
     return (FALSE);
 }
@@ -229,30 +224,30 @@ bdfFreeFontBits(FontPtr pFont)
 
     bitmapFont = (BitmapFontPtr) pFont->fontPrivate;
     bitmapExtra = (BitmapExtraPtr) bitmapFont->bitmapExtra;
-    xfree(bitmapFont->ink_metrics);
+    free(bitmapFont->ink_metrics);
     if(bitmapFont->encoding) {
         nencoding = (pFont->info.lastCol - pFont->info.firstCol + 1) *
 	    (pFont->info.lastRow - pFont->info.firstRow + 1);
         for(i=0; i<NUM_SEGMENTS(nencoding); i++)
-            xfree(bitmapFont->encoding[i]);
+            free(bitmapFont->encoding[i]);
     }
-    xfree(bitmapFont->encoding);
+    free(bitmapFont->encoding);
     for (i = 0; i < bitmapFont->num_chars; i++)
-	xfree(bitmapFont->metrics[i].bits);
-    xfree(bitmapFont->metrics);
+	free(bitmapFont->metrics[i].bits);
+    free(bitmapFont->metrics);
     if (bitmapExtra)
     {
-	xfree (bitmapExtra->glyphNames);
-	xfree (bitmapExtra->sWidths);
-	xfree (bitmapExtra);
+	free (bitmapExtra->glyphNames);
+	free (bitmapExtra->sWidths);
+	free (bitmapExtra);
     }
-    xfree(pFont->info.props);
-    xfree(bitmapFont);
+    free(pFont->info.props);
+    free(bitmapFont);
 }
 
 
 static Bool
-bdfReadCharacters(FontFilePtr file, FontPtr pFont, bdfFileState *pState, 
+bdfReadCharacters(FontFilePtr file, FontPtr pFont, bdfFileState *pState,
 		  int bit, int byte, int glyph, int scan)
 {
     unsigned char *line;
@@ -296,31 +291,30 @@ bdfReadCharacters(FontFilePtr file, FontPtr pFont, bdfFileState *pState,
     }
     if (nchars > INT32_MAX / sizeof(CharInfoRec)) {
 	bdfError("Couldn't allocate pCI (%d*%d)\n", nchars,
-		 sizeof(CharInfoRec));
+		 (int) sizeof(CharInfoRec));
 	goto BAILOUT;
     }
-    ci = (CharInfoPtr) xalloc(nchars * sizeof(CharInfoRec));
+    ci = calloc(nchars, sizeof(CharInfoRec));
     if (!ci) {
 	bdfError("Couldn't allocate pCI (%d*%d)\n", nchars,
-		 sizeof(CharInfoRec));
+		 (int) sizeof(CharInfoRec));
 	goto BAILOUT;
     }
-    bzero((char *)ci, nchars * sizeof(CharInfoRec));
     bitmapFont->metrics = ci;
 
     if (bitmapExtra) {
-	bitmapExtra->glyphNames = (Atom *) xalloc(nchars * sizeof(Atom));
+	bitmapExtra->glyphNames = malloc(nchars * sizeof(Atom));
 	if (!bitmapExtra->glyphNames) {
 	    bdfError("Couldn't allocate glyphNames (%d*%d)\n",
-		     nchars, sizeof(Atom));
+		     nchars, (int) sizeof(Atom));
 	    goto BAILOUT;
 	}
     }
     if (bitmapExtra) {
-	bitmapExtra->sWidths = (int *) xalloc(nchars * sizeof(int));
+	bitmapExtra->sWidths = malloc(nchars * sizeof(int));
 	if (!bitmapExtra->sWidths) {
 	    bdfError("Couldn't allocate sWidth (%d *%d)\n",
-		     nchars, sizeof(int));
+		     nchars, (int) sizeof(int));
 	    return FALSE;
 	}
     }
@@ -383,11 +377,10 @@ bdfReadCharacters(FontFilePtr file, FontPtr pFont, bdfFileState *pState,
 	    if (char_col > pFont->info.lastCol)
 		pFont->info.lastCol = char_col;
 	    if (bdfEncoding[char_row] == (CharInfoPtr *) NULL) {
-		bdfEncoding[char_row] =
-		    (CharInfoPtr *) xalloc(256 * sizeof(CharInfoPtr));
+		bdfEncoding[char_row] = malloc(256 * sizeof(CharInfoPtr));
 		if (!bdfEncoding[char_row]) {
 		    bdfError("Couldn't allocate row %d of encoding (%d*%d)\n",
-			     char_row, INDICES, sizeof(CharInfoPtr));
+			     char_row, INDICES, (int) sizeof(CharInfoPtr));
 		    goto BAILOUT;
 		}
 		for (i = 0; i < 256; i++)
@@ -493,13 +486,11 @@ bdfReadCharacters(FontFilePtr file, FontPtr pFont, bdfFileState *pState,
 
     nencoding = (pFont->info.lastRow - pFont->info.firstRow + 1) *
 	(pFont->info.lastCol - pFont->info.firstCol + 1);
-    bitmapFont->encoding = 
-      (CharInfoPtr **) xcalloc(NUM_SEGMENTS(nencoding),
-                               sizeof(CharInfoPtr*));
+    bitmapFont->encoding = calloc(NUM_SEGMENTS(nencoding),sizeof(CharInfoPtr*));
     if (!bitmapFont->encoding) {
 	bdfError("Couldn't allocate ppCI (%d,%d)\n",
                  NUM_SEGMENTS(nencoding),
-                 sizeof(CharInfoPtr*));
+                 (int) sizeof(CharInfoPtr*));
 	goto BAILOUT;
     }
     pFont->info.allExist = TRUE;
@@ -519,12 +510,12 @@ bdfReadCharacters(FontFilePtr file, FontPtr pFont, bdfFileState *pState,
                 else {
                     if (!bitmapFont->encoding[SEGMENT_MAJOR(i)]) {
                         bitmapFont->encoding[SEGMENT_MAJOR(i)]=
-                            (CharInfoPtr*)xcalloc(BITMAP_FONT_SEGMENT_SIZE,
-                                                  sizeof(CharInfoPtr));
+                            calloc(BITMAP_FONT_SEGMENT_SIZE,
+                                   sizeof(CharInfoPtr));
                         if (!bitmapFont->encoding[SEGMENT_MAJOR(i)])
                             goto BAILOUT;
                     }
-                    ACCESSENCODINGL(bitmapFont->encoding,i) = 
+                    ACCESSENCODINGL(bitmapFont->encoding,i) =
                         bdfEncoding[char_row][char_col];
                 }
                 i++;
@@ -533,12 +524,12 @@ bdfReadCharacters(FontFilePtr file, FontPtr pFont, bdfFileState *pState,
     }
     for (i = 0; i < 256; i++)
 	if (bdfEncoding[i])
-	    xfree(bdfEncoding[i]);
+	    free(bdfEncoding[i]);
     return (TRUE);
 BAILOUT:
     for (i = 0; i < 256; i++)
 	if (bdfEncoding[i])
-	    xfree(bdfEncoding[i]);
+	    free(bdfEncoding[i]);
     /* bdfFreeFontBits will clean up the rest */
     return (FALSE);
 }
@@ -615,21 +606,20 @@ bdfReadProperties(FontFilePtr file, FontPtr pFont, bdfFileState *pState)
     pFont->info.props = NULL;
     pFont->info.nprops = 0;
 
-    stringProps = (char *) xalloc((nProps + BDF_GENPROPS) * sizeof(char));
+    stringProps = malloc((nProps + BDF_GENPROPS) * sizeof(char));
     pFont->info.isStringProp = stringProps;
     if (stringProps == NULL) {
 	bdfError("Couldn't allocate stringProps (%d*%d)\n",
-		 (nProps + BDF_GENPROPS), sizeof(Bool));
+		 (nProps + BDF_GENPROPS), (int) sizeof(Bool));
 	goto BAILOUT;
     }
-    pFont->info.props = props = (FontPropPtr) xalloc((nProps + BDF_GENPROPS) *
-						     sizeof(FontPropRec));
+    pFont->info.props = props = calloc(nProps + BDF_GENPROPS,
+				       sizeof(FontPropRec));
     if (props == NULL) {
 	bdfError("Couldn't allocate props (%d*%d)\n", nProps + BDF_GENPROPS,
-						      sizeof(FontPropRec));
+						   (int) sizeof(FontPropRec));
 	goto BAILOUT;
     }
-    bzero((char *)props, (nProps + BDF_GENPROPS) * sizeof(FontPropRec));
 
     nextProp = 0;
     props_left = nProps;
@@ -770,11 +760,11 @@ bdfReadProperties(FontFilePtr file, FontPtr pFont, bdfFileState *pState)
     return (TRUE);
 BAILOUT:
     if (pFont->info.isStringProp) {
-	xfree(pFont->info.isStringProp);
+	free(pFont->info.isStringProp);
 	pFont->info.isStringProp = NULL;
     }
     if (pFont->info.props) {
-	xfree(pFont->info.props);
+	free(pFont->info.props);
 	pFont->info.props = NULL;
     }
     while (line && bdfIsPrefix(line, "ENDPROPERTIES"))
@@ -792,7 +782,7 @@ bdfUnloadFont(FontPtr pFont)
 }
 
 int
-bdfReadFont(FontPtr pFont, FontFilePtr file, 
+bdfReadFont(FontPtr pFont, FontFilePtr file,
 	    int bit, int byte, int glyph, int scan)
 {
     bdfFileState state;
@@ -808,12 +798,12 @@ bdfReadFont(FontPtr pFont, FontFilePtr file,
     if (!bdfReadHeader(file, &state))
 	goto BAILOUT;
 
-    bitmapFont = (BitmapFontPtr) xalloc(sizeof(BitmapFontRec));
+    bitmapFont = calloc(1, sizeof(BitmapFontRec));
     if (!bitmapFont) {
-      bdfError("Couldn't allocate bitmapFontRec (%d)\n", sizeof(BitmapFontRec));
+	bdfError("Couldn't allocate bitmapFontRec (%d)\n",
+		 (int) sizeof(BitmapFontRec));
 	goto BAILOUT;
     }
-    bzero((char *)bitmapFont, sizeof(BitmapFontRec));
 
     pFont->fontPrivate = (pointer) bitmapFont;
     bitmapFont->metrics = 0;
@@ -822,13 +812,13 @@ bdfReadFont(FontPtr pFont, FontFilePtr file,
     bitmapFont->encoding = 0;
     bitmapFont->pDefault = NULL;
 
-    bitmapFont->bitmapExtra = (BitmapExtraPtr) xalloc(sizeof(BitmapExtraRec));
+    bitmapFont->bitmapExtra = calloc(1, sizeof(BitmapExtraRec));
     if (!bitmapFont->bitmapExtra) {
-      bdfError("Couldn't allocate bitmapExtra (%d)\n", sizeof(BitmapExtraRec));
+	bdfError("Couldn't allocate bitmapExtra (%d)\n",
+		 (int) sizeof(BitmapExtraRec));
         goto BAILOUT;
     }
-    bzero((char *)bitmapFont->bitmapExtra, sizeof(BitmapExtraRec));
-    
+
     bitmapFont->bitmapExtra->glyphNames = 0;
     bitmapFont->bitmapExtra->sWidths = 0;
 
@@ -848,7 +838,7 @@ bdfReadFont(FontPtr pFont, FontFilePtr file,
 	    cols = pFont->info.lastCol - pFont->info.firstCol + 1;
 	    r = r - pFont->info.firstRow;
 	    c = c - pFont->info.firstCol;
-	    bitmapFont->pDefault = ACCESSENCODING(bitmapFont->encoding, 
+	    bitmapFont->pDefault = ACCESSENCODING(bitmapFont->encoding,
                                                  r * cols + c);
 	}
     }
@@ -871,7 +861,7 @@ bdfReadFont(FontPtr pFont, FontFilePtr file,
         bdfError("Failed to add bitmap ink metrics\n");
         goto BAILOUT;
       }
-    }    
+    }
     if (bitmapFont->bitmapExtra)
 	bitmapFont->bitmapExtra->info.inkMetrics = pFont->info.inkMetrics;
 
@@ -936,7 +926,7 @@ bdfPadToTerminal(FontPtr pFont)
 
     bitmapFont = (BitmapFontPtr) pFont->fontPrivate;
 
-    bzero(&new, sizeof(CharInfoRec)); 
+    bzero(&new, sizeof(CharInfoRec));
     new.metrics.ascent = pFont->info.fontAscent;
     new.metrics.descent = pFont->info.fontDescent;
     new.metrics.leftSideBearing = 0;
@@ -945,14 +935,14 @@ bdfPadToTerminal(FontPtr pFont)
     new_size = BYTES_FOR_GLYPH(&new, pFont->glyph);
 
     for (i = 0; i < bitmapFont->num_chars; i++) {
-	new.bits = (char *) xalloc(new_size);
+	new.bits = malloc(new_size);
 	if (!new.bits) {
           bdfError("Couldn't allocate bits (%d)\n", new_size);
 	    return FALSE;
-      }
+	}
 	FontCharReshape(pFont, &bitmapFont->metrics[i], &new);
         new.metrics.attributes = bitmapFont->metrics[i].metrics.attributes;
-	xfree(bitmapFont->metrics[i].bits);
+	free(bitmapFont->metrics[i].bits);
 	bitmapFont->metrics[i] = new;
     }
     bitmapExtra = bitmapFont->bitmapExtra;
