@@ -3,6 +3,10 @@
 #endif
 #include "stubs.h"
 
+#ifdef __SUNPRO_C
+#pragma weak ClientSignal
+#endif
+
 weak Bool
 ClientSignal(ClientPtr client)
 {
